LaviRot is a Python library for rotordynamics analysis.
See the `documentation <https://raphaeltimbo.github.io/LaviRot/>`_.

.. image:: https://travis-ci.org/raphaeltimbo/LaviRot.svg?branch=master
   :target: https://travis-ci.org/raphaeltimbo/LaviRot

.. image:: https://ci.appveyor.com/api/projects/status/aoh7th699g4rksft/branch/master?svg=true
   :target: https://ci.appveyor.com/project/raphaeltimbo/lavirot